@@ -34,7 +34,7 @@ Readonly::Scalar our $WIDTH_SEC => 52;
 Readonly::Scalar our $WIDTH_SPACE => 1;
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -466,8 +466,13 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<Curses::UI>,
-L<Curses::UI::Widget>.
+=over
+
+=item L<Task::Curses::UI>
+
+Install the Curses::UI modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -481,7 +486,8 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © 2014-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 DEDICATION
 
@@ -491,6 +497,6 @@ tty-clock program.
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
